<?php

/**
 * @mainpage SMS bezpośredni
 * 
 * @section preambule Definicje
 * 
 * W niniejszym dokumencie zastosowano następujące słownictwo:
 * - \e Partner - użytkownik systemu Cashbill uruchamiający usługę SMS Bezpośredni.
 * - \e Klient - użytkownik sieci GSM korzystający z usługi partnera.
 *  
 * @section briefdesc Opis usługi
 * 
 * Usługa SMS bezpośredni opiera się na bezpośredniej komunikacji SMS pomiędzy
 * partnerem, a klientem końcowym. Każdy SMS wysłany przez klienta końcowego zostaje
 * dostarczony do systemu informatycznego partnera, który może w dowolnej chwili
 * odpowiedzieć wiadomością.
 * 
 * @par System Cashbill nie ingeruje w żadnen sposób w przesyłane treści.
 * 
 * W zależności od wariantu podpisanej umowy wysyłanie SMS może zostać obwarowane dodatkowymi ograniczeniami.
 * 
 * Do uruchomienia usługi SMS bezpośredni konieczne jest przygotowanie aplikacji
 * obsługującej wiadomości. Gotowe rozwiązania są dostępne w pakiecie instalacyjnym,
 * jednak do ich uruchomienia niezbędna jest ingerencja programisty.
 * 
 * @subsection requirements Wymagania
 *
 * Aby uruchomić SMS bezpośredni partner musi spełnić następujące wymagania:
 * 
 *  - Formalne:
 *    -# Założenie konta w systemie Cashbill.
 *    -# Dostarczenie do personelu Cashbill regulaminu usługi, którą będzie obsługiwać SMS bezpośredni.
 *    -# Akceptacja regulaminu przez operatorów sieci komórkowych, w których będzie działała usługa.
 *    -# Publikacja zaakceptowanego regulaminu.  
 *  - Techniczne:
 *    -# Dostępny w publicznej sieci internet serwer zdolny do komunikacji SOAP.
 * 
 * 
 */

/**
 * 
 * @page conventions Konwencje kodowania i nazewnictwa
 * 
 * @section naming Konwencje nazewnicze
 * 
 * W niniejszej aplikacji i przykładach stosowane jest jednolite nazewnictwo klas, zmiennych, metod i funkcji.
 * Wszystkie nazwy zaczynają się od małej litery, a kolejne słowa w nazwie zaczynają się dużą literą, np:
 * \e przykładowaNazwaPliku. 
 * 
 * @subsection class Deklaracje i definicje klas
 * - przedrostki
 *  -# przedrostek \e i stosowany jest dla interface, na przykład: \e iInterface
 *  -# przedrostek \e a stosowany jest dla klas abstrakcyjnych, na przykład \e aAbstrakt
 *  -# przedrostek \e c stosowany jest dla pozostałych klas, na przykład \e cKlasa
 *  
 * @subsection var Zmienne
 *  - Nazwy zmiennych podlegają standardowym konwencjom wielkości liter, np: $przykladowaZmienna.
 *  - API bramki nie korzysta z żadnych zmiennych globalnych.
 *  
 * @subsection const Stałe
 *  - Nazwy stałych zawierają wyłącznie duże litery. Słowa rozdzielane są znakiem podkreślenia, np: PRZYKLADOWA_STALA
 *  - API bramka SMS Cashbill nie korzysta z żadnych stałych globalnych.
 *     
 * @section code Konwencje kodowania
 * 
 * API bramki Cashbill jest napisane według paradygmatu \e fluid. Metody przeprowadzające
 * operacje na obiekcie zwracają ten sam obiekt, umożliwiając łączenie kolejnych wywołań
 * w mniejszej liczbie linii kodu.
 * 
 * Dlatego kod:
 * 
 * @code
 * 
 * $smsGateway->addReportHandler  ( new cReportLogger()   );
 * $smsGateway->addSMSHandler     ( new cSMSLogger()      );
 * $smsGateway->addSMSErrorHandler( new cSMSErrorLogger() );
 * 
 * @endcode
 * 
 * Jest równoważny:
 * 
 * @code
 * 
 * $smsGateway->addReportHandler  ( new cReportLogger()   )
 *            ->addSMSHandler     ( new cSMSLogger()      )
 *            ->addSMSErrorHandler( new cSMSErrorLogger() );
 * 
 * @endcode
 * 
 * @section examples Konwencje stosowane w przykładach
 * 
 * We wszystkich przykładach zawartych w niniejszej dokumentacji zastosowanie
 * mają następujące konwencje zapisu:
 * 
 * -# W nawiasach trójkątnych zawarto treści, które partner musi uzupełnić.
 *    Np. <klucz tajny>, <hasło> itp. Należy pamiętać, by podawane ciągi
 *    znaków zawierać w cudzysłowach, np. w miejsce <login> wpisujemy "mójlogin"
 * -# W nawiasach kwadratowych zawarto parametry opcjonalne, których nie
 *    trzeba umieszczać. Zapis <login> [, <hasło>] powinien być zastąpiony
 *    przez "mójlogin" lub "mójlogin","mojehasło".
 */

header( 'Content-type: text/html, encoding=utf8'); echo show_source( __FILE__ );

?>